@@ -2,7 +2,7 @@ import glob
 import re
 import starepandas
 from .modis import Mod09GA, Mod05, Mod09, Mod03
-from .viirsl2 import VNP02DNB, VNP03DNB, VNP03MOD, CLDMSKL2VIIRS
+from .viirsl2 import VNP02DNB, VNP03DNB, VNP03MOD, CLDMSKL2VIIRS, VNP09
 from .ssmis import SSMIS
 from .atms import ATMS
 
@@ -90,6 +90,7 @@ granule_factory_library = {
     'VNP02DNB|VJ102DNB': VNP02DNB,
     'VNP03DNB|VJ103DNB': VNP03DNB,
     'VNP03MOD|VJ103MOD': VNP03MOD,
+    'VNP09': VNP09,
     'CLDMSKL2VIIRS': CLDMSKL2VIIRS,
     'SSMIS': SSMIS,
     'ATMS': ATMS
