@@ -7,16 +7,16 @@ import pystare
 
 class SSMIS(Granule):
     
-    def __init__(self, file_path, sidecar_path=None):                
+    def __init__(self, file_path, sidecar_path=None, scans=['S1', 'S2', 'S3', 'S4']):
         super().__init__(file_path, sidecar_path)
         self.netcdf = starepandas.io.s3.nc4_dataset_wrapper(self.file_path, 'r', format='NETCDF4')
         self.lat = None
         self.lon = None
-        self.timestamps = None
+        self.timestamps = {}
         self.data = {'S1': {}, 'S2': {}, 'S3': {}, 'S4': {}}
         self.stare = None
         self.nom_res = ''
-        self.scans = ['S1', 'S2', 'S3', 'S4']
+        self.scans = scans
 
     def read_latlon(self):
         self.lat = {}
@@ -46,54 +46,59 @@ class SSMIS(Granule):
         return numpy.array(timestamps)
             
     def read_timestamps(self):
-        self.timestamps = {}
-        ts = self.read_timestamp_scan('S1')
-        ts_len = ts.shape[0]
-        ts = numpy.repeat(ts, 90)
-        ts = ts.reshape(ts_len, 90)
-        self.timestamps['S1'] = ts
+        if 'S1' in self.scans:
+            ts = self.read_timestamp_scan('S1')
+            ts_len = ts.shape[0]
+            ts = numpy.repeat(ts, 90)
+            ts = ts.reshape(ts_len, 90)
+            self.timestamps['S1'] = ts
 
-        ts = self.read_timestamp_scan('S2')
-        ts_len = ts.shape[0]
-        ts = numpy.repeat(ts, 90)
-        ts = ts.reshape(ts_len, 90)
-        self.timestamps['S2'] = ts
+        if 'S2' in self.scans:
+            ts = self.read_timestamp_scan('S2')
+            ts_len = ts.shape[0]
+            ts = numpy.repeat(ts, 90)
+            ts = ts.reshape(ts_len, 90)
+            self.timestamps['S2'] = ts
 
-        ts = self.read_timestamp_scan('S3')
-        ts_len = ts.shape[0]
-        ts = numpy.repeat(ts, 180)
-        ts = ts.reshape(ts_len, 180)
-        self.timestamps['S3'] = ts
+        if 'S3' in self.scans:
+            ts = self.read_timestamp_scan('S3')
+            ts_len = ts.shape[0]
+            ts = numpy.repeat(ts, 180)
+            ts = ts.reshape(ts_len, 180)
+            self.timestamps['S3'] = ts
 
-        ts = self.read_timestamp_scan('S4')
-        ts_len = ts.shape[0]
-        ts = numpy.repeat(ts, 180)
-        ts = ts.reshape(ts_len, 180)
-        self.timestamps['S4'] = ts
+        if 'S4' in self.scans:
+            ts = self.read_timestamp_scan('S4')
+            ts_len = ts.shape[0]
+            ts = numpy.repeat(ts, 180)
+            ts = ts.reshape(ts_len, 180)
+            self.timestamps['S4'] = ts
 
     def read_data(self):
-        self.data['S1']['Tc1'] = self.netcdf.groups['S1']['Tc'][:, :, 0]
-        self.data['S1']['Tc2'] = self.netcdf.groups['S1']['Tc'][:, :, 1]
-        self.data['S1']['Tc3'] = self.netcdf.groups['S1']['Tc'][:, :, 2]
+        if 'S1' in self.scans:
+            self.data['S1']['Tc1'] = self.netcdf.groups['S1']['Tc'][:, :, 0]
+            self.data['S1']['Tc2'] = self.netcdf.groups['S1']['Tc'][:, :, 1]
+            self.data['S1']['Tc3'] = self.netcdf.groups['S1']['Tc'][:, :, 2]
 
-        self.data['S2']['Tc1'] = self.netcdf.groups['S2']['Tc'][:, :, 0]
-        self.data['S2']['Tc2'] = self.netcdf.groups['S2']['Tc'][:, :, 1]
+        if 'S2' in self.scans:
+            self.data['S2']['Tc1'] = self.netcdf.groups['S2']['Tc'][:, :, 0]
+            self.data['S2']['Tc2'] = self.netcdf.groups['S2']['Tc'][:, :, 1]
 
-        self.data['S3']['Tc1'] = self.netcdf.groups['S3']['Tc'][:, :, 0]
-        self.data['S3']['Tc2'] = self.netcdf.groups['S3']['Tc'][:, :, 1]
-        self.data['S3']['Tc3'] = self.netcdf.groups['S3']['Tc'][:, :, 2]
-        self.data['S3']['Tc4'] = self.netcdf.groups['S3']['Tc'][:, :, 3]
+        if 'S3' in self.scans:
+            self.data['S3']['Tc1'] = self.netcdf.groups['S3']['Tc'][:, :, 0]
+            self.data['S3']['Tc2'] = self.netcdf.groups['S3']['Tc'][:, :, 1]
+            self.data['S3']['Tc3'] = self.netcdf.groups['S3']['Tc'][:, :, 2]
+            self.data['S3']['Tc4'] = self.netcdf.groups['S3']['Tc'][:, :, 3]
 
-        self.data['S4']['Tc1'] = self.netcdf.groups['S4']['Tc'][:, :, 0]
-        self.data['S4']['Tc2'] = self.netcdf.groups['S4']['Tc'][:, :, 1]
-
-        self.read_timestamps()
+        if 'S4' in self.scans:
+            self.data['S4']['Tc1'] = self.netcdf.groups['S4']['Tc'][:, :, 0]
+            self.data['S4']['Tc2'] = self.netcdf.groups['S4']['Tc'][:, :, 1]
 
     def add_sids(self, adapt_resolution=True):
         self.sids = {}
         for scan in self.scans:
             self.sids[scan] = pystare.from_latlon2D(lat=self.lat[scan], lon=self.lon[scan],
-                                                     adapt_resolution=adapt_resolution)
+                                                    adapt_resolution=adapt_resolution)
 
     def read_sidecar_index(self, sidecar_path=None):
         self.sids = {}
